==> alfred_osint-0.2.3.tar.gz: alfred_osint-0.2.3/alfred_osint/lang/ar.py <==
# ar.py
# Arabic

encrypt1 = "تشفير المفتاح..."

title1 = "شكرا جزيلا لشركائنا!"

disclamer = "     تنويه: لا تضمن جميع المواقع أو الوكلاء العمل! \n     باستخدامك، فأنت تتحمل المسؤولية الكاملة عن أفعالك"

targetusernames = "أسماء المستخدمين المستهدفة:"

version = "الإصدار"

config1 = "ملف التكوين موجود: "
config2 = "ملف التحديث موجود: "
config3 = "المجلد موجود بالفعل: "
config4 = "البحث عن تحديثات؟ [Y / n]: ⤷ "
config5 = "تحرير التكوين؟ [Y / n]: ⤷ "
config6 = "ماذا تريد تغيير؟ ⤷ "
config7 = "إنشاء مجلد: "
config8 = "المجلد موجود بالفعل: "

configOption1 = "[1] البحث عن تحديثات: "
configOption2 = "[2] إظهار النصائح: "
configOption3 = "[3] مسار تنزيل الموقع: "
configOption4 = "[4] المستعرض: "
configOption5 = "[5] اللغة: "
configOptionA = "[A] تنظيف Alfred. (يزيل الملفات المؤقتة)"
configOptionB = "[B] أدوات المطور."

configOption1Message = "حسنا! [checkforupdates] تم تعيينه على نعم. يتغير إلى لا"
configOption2Message = "حسنا! [showtips] تم تعيينه على نعم. يتغير إلى لا"
configOption3Message = "المسار الجديد: ⤷ "
configOption4Message = """
الأنواع المدعومة:
   Firefox
   Edge
   Chrome
"""
configOption5Message = """
الرجاء إدخال رمز اللغة الخاص بك
اللغة المدعومة:
   it = Italian
   en = English
   il = Hebrew 
   ar = Arabic 
   es = Spanish
"""
configOptionAMessage = "تمت!"
configOptionBMessage = "مرحبا بك في قائمة المطور!"

configOption1Message2 = "حسنا! [checkforupdates] تم تعيينه على لا. يتغير إلى نعم"
configOption2Message2 = "حسنا! [showtips] تم تعيينه على لا. يتغير إلى نعم"
configOptionBMessage2 = "لا تعطي المفاتيح التالية لأي شخص غير مطور Alfred."
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "الهدف: ⤷ "
browser = "المستعرض: "

file_not_found = "ملف مفقود: {filename}"
permission_denied = "تم رفض الإذن لـ {operation} على {path}"

note = "ملحوظة! "
path = "المسار: ⤷ "
warning1 = (
    "قد لا تسمح العديد من المواقع بتنزيل ملفات مواقعها. استخدم على مسؤوليتك الخاصة."
)
warning2 = "استخدام Webscraper بطيء جدًا."
warning3 = (
    "هذا هو إطلاقك الأول: D قد تحتاج إلى إعادة تشغيل Alfred لاستخدام جميع الوحدات"
)
warning4 = "أنت تستخدم إصدارًا مسبقًا من Alfred!"

confirm1 = "هل تريد تنزيل الصور / مقاطع الفيديو؟ [Y / n] ⤷ "
confirm2 = "تشغيل مرة أخرى؟ [Y / n] ⤷ "

prompt1 = "أدخل الموقع مرة أخرى: ⤷ "
prompt2 = "يرجى إبلاغنا بأي أخطاء أو أخطاء في مستودعنا أو خادم Discord الخاص بنا."
prompt3 = "يمكنك تعطيل التحديث في ملف التكوين"
prompt4 = "انضم إلى Discord: https://discord.gg/xrdjxyuSQt"
prompt5 = "حسنا! سأسأل لاحقا...."
prompt6 = "المواقع التي لا تعمل..."

download1 = "تنزيل "
updates = "التحديثات ممكنة!"

idk1 = "لا أعرف ما تقصد...."
idk2 = "لا أعرف ما تقصد. سأطلب لاحقًا"
idk3 = "لست متأكدًا ... ولكن يمكنك التحقق هنا: "
scan1 = "البحث عن مواقع تحتوي على: "

status1 = "يعمل...."
status2 = "إنشاء / الكتابة فوق ملف الحفظ."
status3 = "إعادة التثبيت............"
status4 = "العودة إلى Alfred قريبًا ..."
status5 = "اختبار....."
status6 = "توقف ..... تم حفظها في captured / working.txt"
status7 = "توقف........"

save1 = "نتائج محفوظة إلى"
save2 = "تم حفظ النتائج في ملف"

error1 = "خطأ في الإذن"
error2 = "خطأ في النوع"
error3 = "لا يمكن العثور على ملف الحفظ!"
error4 = "الدليل غير موجود."
error5 = "لا يمكن العثور على الملفات الضرورية. محاولة إعادة تثبيت Alfred"
error6 = (
    "أوه خطأ! يبدو أن الاتصال لا يعمل. تحقق من اتصالك أو الوكيل ، ثم حاول مرة أخرى:"
)
error7 = "لا يمكن العثور على ملف الموقع"
error8 = "خطأ في تنزيل محتوى الويب!"
error9 = "خطأ في ملف الموقع"
error10 = "اختيار غير صالح لبرنامج التشغيل."
error11 = "حدث خطأ: "

fileshare1 = "[*] استمع كـ"
fileshare2 = "متصل."
fileshare3 = "استلام"

wikiOption1 = "[1] التثبيت"
wikiOption2 = "[2] خيارات"
wikiOption3 = "[3] أخطاء"
wikiOption4 = "[4] Alfred Dark"
wikiOption5 = "[5] وحدات"

wikilist = "يمكنك العثور على معلومات عنها هنا: "

rqUname = "اسم المستخدم المطلوب: "

sender1 = "[+] الاتصال بـ"
sender2 = "[+] متصل."
sender3 = "إرسال."
sender4 = "ملف للإرسال: ⤷ "

fs1 = "خادم مضيف؟ [Y/N]: ⤷ "
fs2 = "في انتظار الاتصال بالمضيف!"
fs3 = "انتظار اتصال العميل!"

siteDl1 = "إجمالي ملفات البرامج النصية في الصفحة:"
siteDl2 = "إجمالي ملفات CSS في الصفحة:"

==> alfred_osint-0.2.3.4.tar.gz: alfred_osint-0.2.3.4/alfred_osint/lang/ar.py <==
# ar.py
# Arabic

encrypt1 = "تشفير المفتاح..."

title1 = "شكرا جزيلا لشركائنا!"

disclamer = "     تنويه: لا تضمن جميع المواقع أو الوكلاء العمل! \n     باستخدامك، فأنت تتحمل المسؤولية الكاملة عن أفعالك"

targetusernames = "أسماء المستخدمين المستهدفة:"

version = "الإصدار"

config1 = "ملف التكوين موجود "
config2 = "ملف التحديث موجود "
config3 = "المجلد موجود بالفعل: "
config4 = "البحث عن تحديثات؟ [Y / n]: ⤷ "
config5 = "تحرير التكوين؟ [Y / n]: ⤷ "
config6 = "ماذا تريد تغيير؟ ⤷ "
config7 = "إنشاء مجلد: "
config8 = "المجلد موجود بالفعل: "

configOption1 = "[1] البحث عن تحديثات: "
configOption2 = "[2] إظهار النصائح: "
configOption3 = "[3] مسار تنزيل الموقع: "
configOption4 = "[4] المستعرض: "
configOption5 = "[5] اللغة: "
configOptionA = "[A] تنظيف Alfred. (يزيل الملفات المؤقتة)"
configOptionB = "[B] أدوات المطور."

configOption1Message = "حسنا! [checkforupdates] تم تعيينه على نعم. يتغير إلى لا"
configOption2Message = "حسنا! [showtips] تم تعيينه على نعم. يتغير إلى لا"
configOption3Message = "المسار الجديد: ⤷ "
configOption4Message = """
الأنواع المدعومة:
   Firefox
   Edge
   Chrome
"""
configOption5Message = """
الرجاء إدخال رمز اللغة الخاص بك
اللغة المدعومة:
   it = Italian
   en = English
   il = Hebrew 
   ar = Arabic 
   es = Spanish
   de = German
   ru = الروسية
   hi = هندي
"""
configOptionAMessage = "تمت!"
configOptionBMessage = "مرحبا بك في قائمة المطور!"

configOption1Message2 = "حسنا! [checkforupdates] تم تعيينه على لا. يتغير إلى نعم"
configOption2Message2 = "حسنا! [showtips] تم تعيينه على لا. يتغير إلى نعم"
configOptionBMessage2 = "لا تعطي المفاتيح التالية لأي شخص غير مطور Alfred."
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "الهدف: ⤷ "
browser = "المستعرض: "

file_not_found = "ملف مفقود: {filename}"
permission_denied = "تم رفض الإذن لـ {operation} على {path}"

note = "ملحوظة! "
path = "المسار: ⤷ "
warning1 = (
    "قد لا تسمح العديد من المواقع بتنزيل ملفات مواقعها. استخدم على مسؤوليتك الخاصة."
)
warning2 = "استخدام Webscraper بطيء جدًا."
warning3 = (
    "هذا هو إطلاقك الأول: D قد تحتاج إلى إعادة تشغيل Alfred لاستخدام جميع الوحدات"
)
warning4 = "أنت تستخدم إصدارًا مسبقًا من Alfred!"

confirm1 = "هل تريد تنزيل الصور / مقاطع الفيديو؟ [Y / n] ⤷ "
confirm2 = "تشغيل مرة أخرى؟ [Y / n] ⤷ "

prompt1 = "أدخل الموقع مرة أخرى: ⤷ "
prompt2 = "يرجى إبلاغنا بأي أخطاء أو أخطاء في مستودعنا أو خادم Discord الخاص بنا."
prompt3 = "يمكنك تعطيل التحديث في ملف التكوين"
prompt4 = "انضم إلى Discord: https://discord.gg/xrdjxyuSQt"
prompt5 = "حسنا! سأسأل لاحقا...."
prompt6 = "المواقع التي لا تعمل..."

download1 = "تنزيل "
updates = "التحديثات ممكنة!"

idk1 = "لا أعرف ما تقصد...."
idk2 = "لا أعرف ما تقصد. سأطلب لاحقًا"
idk3 = "لست متأكدًا ... ولكن يمكنك التحقق هنا: "
scan1 = "البحث عن مواقع تحتوي على: "

status1 = "يعمل...."
status2 = "إنشاء / الكتابة فوق ملف الحفظ."
status3 = "إعادة التثبيت............"
status4 = "العودة إلى Alfred قريبًا ..."
status5 = "اختبار....."
status6 = "توقف ..... تم حفظها في captured / working.txt"
status7 = "توقف........"

save1 = "نتائج محفوظة إلى"
save2 = "تم حفظ النتائج في ملف"

error1 = "خطأ في الإذن"
error2 = "خطأ في النوع"
error3 = "لا يمكن العثور على ملف الحفظ!"
error4 = "الدليل غير موجود."
error5 = "لا يمكن العثور على الملفات الضرورية. محاولة إعادة تثبيت Alfred"
error6 = (
    "أوه خطأ! يبدو أن الاتصال لا يعمل. تحقق من اتصالك أو الوكيل ، ثم حاول مرة أخرى:"
)
error7 = "لا يمكن العثور على ملف الموقع"
error8 = "خطأ في تنزيل محتوى الويب!"
error9 = "خطأ في ملف الموقع"
error10 = "اختيار غير صالح لبرنامج التشغيل."
error11 = "حدث خطأ: "

fileshare1 = "[*] استمع كـ"
fileshare2 = "متصل."
fileshare3 = "استلام"

wikiOption1 = "[1] التثبيت"
wikiOption2 = "[2] خيارات"
wikiOption3 = "[3] أخطاء"
wikiOption4 = "[4] Alfred Dark"
wikiOption5 = "[5] وحدات"

wikilist = "يمكنك العثور على معلومات عنها هنا: "

rqUname = "اسم المستخدم المطلوب: "

sender1 = "[+] الاتصال بـ"
sender2 = "[+] متصل."
sender3 = "إرسال."
sender4 = "ملف للإرسال: ⤷ "

fs1 = "خادم مضيف؟ [Y/N]: ⤷ "
fs2 = "في انتظار الاتصال بالمضيف!"
fs3 = "انتظار اتصال العميل!"

siteDl1 = "إجمالي ملفات البرامج النصية في الصفحة:"
siteDl2 = "إجمالي ملفات CSS في الصفحة:"
